@@ -48,7 +48,7 @@ test_that("Numerical matrices",{
   test_mx <- matrix(c(1, 1.11, 1.25,
                       2.50, 2.55, 2.45,
                       3.2313, 3, pi),
-                    ncol = 3, byrow=TRUE)
+                    ncol = 3, byrow = TRUE)
   expect_equivalent(txtRound(test_mx, 1),
                     t(apply(test_mx, 1, function(x) sprintf("%.1f", x))))
 
@@ -77,10 +77,10 @@ test_that("Numerical matrices",{
   expect_equivalent(txtRound(test_mx, 1, excl.rows = "a")["c", 3],
                     sprintf("%.1f", test_mx["c", 3]))
 
-  expect_equivalent(txtRound(matrix(c(NA, 2.22), ncol=1), 1)[1,1],
+  expect_equivalent(txtRound(matrix(c(NA, 2.22), ncol = 1), 1)[1,1],
                     "")
 
-  expect_equivalent(txtRound(matrix(c(NA, 2.22), ncol=1), 1, txt.NA = "missing")[1,1],
+  expect_equivalent(txtRound(matrix(c(NA, 2.22), ncol = 1), 1, txt.NA = "missing")[1,1],
                     "missing")
 
   expect_error(txtRound(test_mx, digits = c(2, 3, 4, 5)))
@@ -93,7 +93,7 @@ test_that("Character matrices",{
   test_mx <- matrix(c(1, 1.11, 1.25,
                       2.50, 2.55, 2.45,
                       3.2313, 3, pi),
-                    ncol = 3, byrow=TRUE)
+                    ncol = 3, byrow = TRUE)
   ch_test_mx <- cbind(test_mx, "a")
 
   expect_equivalent(txtRound(ch_test_mx, 1)[,1:ncol(test_mx)],
@@ -115,7 +115,7 @@ test_that("Supplying a data.frame",{
   test_df <- matrix(c(1, 1.11, 1.25,
                       2.50, 2.55, 2.45,
                       3.2313, 3, pi),
-                    ncol = 3, byrow=TRUE) %>%
+                    ncol = 3, byrow = TRUE) %>%
     as.data.frame()
   test_df$text = LETTERS[1:nrow(test_df)]
 
@@ -135,8 +135,8 @@ test_that("Supplying a table",{
 })
 
 test_that("Supplying a vector for the digits",{
-  w <- matrix((1:8)/7, ncol=4)
-  w_out <- txtRound(w, digits=1:4)
+  w <- matrix((1:8)/7, ncol = 4)
+  w_out <- txtRound(w, digits = 1:4)
   for (digits in 1:4)
     expect_equivalent(w_out[,digits],
                       sprintf(paste0("%.", digits, "f"), w[,digits]),
@@ -158,27 +158,27 @@ test_that("The txtRound should apply a txtInt to the integer section when activa
 
   expect_equal(txtRound(123333.123, digits = 1, txtInt_args = list()),
                "123,333.1")
+
+  expect_equal(txtRound(123333, digits = 0, txtInt_args = list()),
+               "123,333")
 })
 
-
-
 test_that("Numbers that round to 0 should not have -, i.e. no -0.0",{
   expect_equal(txtRound(matrix(-.01), digits = 1),
                matrix("0.0"))
 
   expect_equal(txtRound(matrix("-.01"), digits = 0),
                matrix("0"))
-
 })
 
 test_that("Character vectors work", {
   test_str <- c("AA 2 2A", "-1.2  aaa",
                 "-1", "2.8888")
   correct_str <- c("2.0", "-1.2", "-1.0", "2.9")
-  for (i in 1:length(test_str))
+  for (i in 1:length(test_str)) {
     expect_equivalent(txtRound(test_str[i], digits = 1),
                       correct_str[i], info = paste("Test case", i))
-
+  }
 })
 
 test_that("Keep minimila digits", {
@@ -206,6 +206,18 @@ test_that("Peter's issues raised in #34", {
   expect_silent(txtRound(c(NA, NA, NA, NA)))
 })
 
+test_that("Negative numbers - issue #76", {
+  expect_equal(txtRound(-1.1111, digits = 2),
+               "-1.11")
+
+  expect_equal(txtRound(-0.000000011, digits = 2, digits.nonzero = 4),
+               "0.00")
+
+  expect_equal(txtRound(-0.00011, digits = 2, digits.nonzero = 4),
+               "-0.0001")
+})
+
+
 test_that("Scientific notation",{
   expect_equal(txtRound("1.1234", 1), "1.1")
 
